@@ -155,7 +155,7 @@ box_auth <- function(client_id = "", client_secret = "", interactive = TRUE,
     "https://api.box.com/2.0/folders/0", httr::config(token = box_token)
   )
 
-  if (httr::http_status(test_req)$cat != "success")
+  if (httr::http_status(test_req)$cat != "Success")
     stop("Login at box.com failed; unable to connect to API.")
 
   cr <- httr::content(test_req)
